# pyTRLCConverter <!-- omit in toc -->

## Simple Requirement Example With Project Specific Conversion

The example demonstrates how the requirements in a **single file** are converted to Markdown format **with a project specific conversion**, but **without a translation file** to translate the requirement type attribute name. The pyTRLCConverter will generate a simple output without project-specific conversion functions.

## Issues, Ideas And Bugs

If you have further ideas or you found some bugs, great! Create a [issue](https://github.com/NewTec-GmbH/pyTRLCConverter/issues) or if you are able and willing to fix it by yourself, clone the repository and create a pull request.

## License

The whole source code is published under [GPL-3.0](https://github.com/NewTec-GmbH/pyTRLCConverter/blob/main/LICENSE).
Consider the different licenses of the used third party libraries too!

## Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, shall be licensed as above, without any additional terms or conditions.
